Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/swiift/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/api.py | 164 | 164 | 48 | 38 | 0 | 0%
src/swiift/api/spectra.py | 87 | 0 | 0 | 0 | 0 | 100%
src/swiift/api/utils.py | 12 | 12 | 2 | 0 | 0 | 0%
src/swiift/lib/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/lib/_ph_utils.py | 5 | 2 | 0 | 0 | 0 | 60%
src/swiift/lib/att.py | 21 | 4 | 0 | 0 | 0 | 81%
src/swiift/lib/constants.py | 5 | 0 | 0 | 0 | 0 | 100%
src/swiift/lib/dr.py | 91 | 59 | 2 | 24 | 0 | 28%
src/swiift/lib/graphics.py | 103 | 87 | 2 | 24 | 0 | 13%
src/swiift/lib/numerical.py | 142 | 109 | 85 | 42 | 0 | 18%
src/swiift/lib/phase_shift.py | 43 | 11 | 0 | 0 | 0 | 74%
src/swiift/lib/physics.py | 233 | 151 | 2 | 10 | 0 | 35%
src/swiift/model/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/swiift/model/frac_handlers.py | 118 | 69 | 0 | 16 | 0 | 37%
src/swiift/model/model.py | 282 | 135 | 10 | 58 | 0 | 43%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/helpers.py | 18 | 18 | 0 | 2 | 0 | 0%
tests/model_strategies.py | 27 | 27 | 0 | 0 | 0 | 0%
tests/physical_strategies.py | 22 | 7 | 0 | 0 | 0 | 68%
tests/test_attenuation.py | 83 | 83 | 0 | 0 | 0 | 0%
tests/test_diagnosis.py | 36 | 36 | 28 | 0 | 0 | 0%
tests/test_disp_relations.py | 45 | 45 | 0 | 0 | 0 | 0%
tests/test_domain.py | 92 | 92 | 2 | 10 | 0 | 0%
tests/test_experiment.py | 360 | 360 | 0 | 36 | 0 | 0%
tests/test_fracture.py | 121 | 121 | 2 | 18 | 0 | 0%
tests/test_graphics.py | 11 | 11 | 0 | 2 | 0 | 0%
tests/test_model_objects.py | 9 | 9 | 0 | 0 | 0 | 0%
tests/test_numerical.py | 29 | 29 | 0 | 12 | 0 | 0%
tests/test_param_spectra.py | 50 | 0 | 0 | 4 | 0 | 100%
tests/test_physical_handlers.py | 62 | 62 | 0 | 4 | 0 | 0%
tests/test_physics.py | 149 | 149 | 2 | 22 | 0 | 0%
tests/test_pscattering.py | 35 | 35 | 0 | 4 | 0 | 0%
tests/test_spectrum.py | 73 | 73 | 0 | 22 | 0 | 0%
tests/utils.py | 10 | 0 | 0 | 0 | 0 | 100%
Total | 2538 | 1960 | 185 | 348 | 0 | 20%

No items found using the specified filter.